import { APIClient, BrowserStackOptions, APIFetchOptions } from './api-client';
import { operations } from './generated/openapi';
/**
 * AutomateClient represents a client for interacting with the BrowserStack Automate API.
 * @see https://www.browserstack.com/automate/rest-api
 * @public
 */
export declare class AutomateClient extends APIClient {
    /**
     * Constructs a new instance of the AutomateClient class.
     * @param options - Options to customize the client.
     */
    constructor(options?: BrowserStackOptions);
    /**
     * Recycles the automate key.
     * @param options The fetch options for the request.
     * @returns {} A promise that resolves to the response of the request.
     */
    recycleKey(options?: APIFetchOptions<operations["recycleAutomateKey"]>): Promise<{
        old_key: string;
        new_key: string;
    }>;
    /**
     * Retrieves the automate plan.
     * @param options - The fetch options for the request.
     * @returns A promise that resolves with the automate plan.
     */
    getPlan(options?: APIFetchOptions<operations["getAutomatePlan"]>): Promise<{
        automate_plan: string;
        parallel_sessions_running: number;
        parallel_sessions_max_allowed: number;
        team_parallel_sessions_max_allowed: number;
        queued_sessions: number;
        queued_sessions_max_allowed: number;
    }>;
    /**
     * Retrieves the list of available browsers for BrowserStack Automate.
     * @param options - Optional fetch options for customizing the request.
     * @returns A Promise that resolves to the list of available browsers.
     */
    getBrowsers(options?: APIFetchOptions<operations["getAutomateBrowsers"]>): Promise<({
        browser: string;
        browser_version: string;
    } & {
        os: string;
        os_version: string;
        device: string;
        real_mobile: boolean;
    })[]>;
    /**
     * Retrieves the projects from the BrowserStack Automate API.
     * @param options - The fetch options for the API request.
     * @returns A promise that resolves with the projects data.
     */
    getProjects(options?: APIFetchOptions<operations["getAutomateProjects"]>): Promise<{
        id: number;
        name: string;
        user_id: number;
        group_id: number;
        sub_group_id: number;
        created_at: string;
        updated_at: string;
    }[]>;
    /**
     * Retrieves a project by its ID.
     * @param projectId The ID of the project to retrieve.
     * @param options Additional options for the fetch request.
     * @returns A promise that resolves to the retrieved project.
     */
    getProject(projectId: number, options?: APIFetchOptions<operations["getAutomateProject"]>): Promise<{
        id: number;
        name: string;
        user_id: number;
        group_id: number;
        sub_group_id: number;
        created_at: string;
        updated_at: string;
    } & {
        builds: {
            name: string;
            duration: number;
            status: "running" | "timeout" | "failed" | "done";
            user_id?: number | undefined;
            group_id?: number | undefined;
            sub_group_id?: number | undefined;
            automation_project_id?: number | undefined;
            hashed_id: string;
            build_tag: string;
            delta?: boolean | undefined;
            framework?: string | undefined;
            test_data?: Record<string, never> | undefined;
            created_at?: string | undefined;
            updated_at?: string | undefined;
        }[];
    }>;
    /**
     * Updates a project with the specified ID.
     *
     * @param projectId - The ID of the project to update.
     * @param body - The request body containing the updated project details.
     * @param options - Additional options for the request.
     * @returns A promise that resolves with the updated project.
     */
    updateProject(projectId: number, body: operations["updateAutomateProject"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["updateAutomateProject"]>): Promise<{
        id: number;
        name: string;
        user_id: number;
        group_id: number;
        sub_group_id: number;
        created_at: string;
        updated_at: string;
    }>;
    /**
     * Deletes a project with the specified ID.
     * @param projectId The ID of the project to delete.
     * @param options Additional options for the delete request.
     * @returns A promise that resolves when the project is successfully deleted.
     */
    deleteProject(projectId: number, options?: APIFetchOptions<operations["deleteAutomateProject"]>): Promise<{
        status?: string | undefined;
        message?: string | undefined;
    }>;
    /**
     * Retrieves the badge key for a specific project.
     * @param projectId The ID of the project.
     * @param options Additional options for the request.
     * @returns A promise that resolves to the badge key.
     */
    getBadgeKey(projectId: number, options?: APIFetchOptions<operations["getAutomateProjectBadgeKey"]>): Promise<string>;
    /**
     * Retrieves a list of builds from the BrowserStack Automate API.
     *
     * @param query - Optional query parameters for filtering the builds.
     * @param options - Optional fetch options for the API request.
     * @returns A Promise that resolves to an array of automation builds.
     */
    getBuilds(query?: operations["getAutomateBuilds"]["parameters"]["query"], options?: APIFetchOptions<operations["getAutomateBuilds"]>): Promise<{
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        user_id?: number | undefined;
        group_id?: number | undefined;
        sub_group_id?: number | undefined;
        automation_project_id?: number | undefined;
        hashed_id: string;
        build_tag: string;
        delta?: boolean | undefined;
        framework?: string | undefined;
        test_data?: Record<string, never> | undefined;
        created_at?: string | undefined;
        updated_at?: string | undefined;
    }[]>;
    /**
     * Retrieves information about a specific build.
     * @param buildId - The ID of the build.
     * @param options - Additional options for the request.
     * @returns A promise that resolves to the build information.
     */
    getBuild(buildId: string, options?: APIFetchOptions<operations["getAutomateBuild"]>): Promise<{
        sessions: ({
            browser: string;
            browser_version: string;
        } & {
            os: string;
            os_version: string;
            device: string;
            real_mobile: boolean;
        } & {
            hashed_id: string;
            name: string;
            duration: number;
            status: "running" | "timeout" | "failed" | "done";
            browserstack_status: string;
            reason: string;
            build_name: string;
            project_name: string;
            logs: string;
            browser_url: string;
            public_url: string;
            appium_logs_url: string;
            video_url: string;
            browser_console_logs_url: string;
            har_logs_url: string;
            selenium_logs_url: string;
            selenium_telemetry_logs_url: string;
            created_at: string;
        })[];
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        user_id?: number | undefined;
        group_id?: number | undefined;
        sub_group_id?: number | undefined;
        automation_project_id?: number | undefined;
        hashed_id: string;
        build_tag: string;
        delta?: boolean | undefined;
        framework?: string | undefined;
        test_data?: Record<string, never> | undefined;
        created_at?: string | undefined;
        updated_at?: string | undefined;
    }>;
    /**
     * Updates a build in the BrowserStack Automate API.
     *
     * @param buildId - The ID of the build to update.
     * @param body - The request body containing the updated build data.
     * @param options - Additional options for the request.
     * @returns A promise that resolves to the updated build data.
     * @throws {BrowserStackError} If an error occurs during the update.
     */
    updateBuild(buildId: string, body: operations["updateAutomateBuild"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["updateAutomateBuild"]>): Promise<{
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        user_id?: number | undefined;
        group_id?: number | undefined;
        sub_group_id?: number | undefined;
        automation_project_id?: number | undefined;
        hashed_id: string;
        build_tag: string;
        delta?: boolean | undefined;
        framework?: string | undefined;
        test_data?: Record<string, never> | undefined;
        created_at?: string | undefined;
        updated_at?: string | undefined;
    }>;
    /**
     * Deletes a build with the specified ID.
     * @param buildId The ID of the build to delete.
     * @param options Additional options for the delete request.
     * @returns A promise that resolves when the build is successfully deleted.
     */
    deleteBuild(buildId: string, options?: APIFetchOptions<operations["deleteAutomateBuild"]>): Promise<{
        status?: string | undefined;
        message?: string | undefined;
    }>;
    /**
     * Deletes multiple builds from the BrowserStack Automate API.
     * @param buildIds An array of build IDs to be deleted.
     * @param options Additional options for the delete request.
     * @returns A promise that resolves when the delete request is successful.
     */
    deleteBuilds(buildIds: string[], options?: APIFetchOptions<operations["deleteAutomateBuilds"]>): Promise<{
        message?: string | undefined;
    }>;
    /**
     * Retrieves the sessions associated with a specific build.
     *
     * @param buildId - The ID of the build.
     * @param query - Optional query parameters for filtering the sessions.
     * @param options - Optional fetch options for the request.
     * @returns A promise that resolves to an array of automation sessions.
     */
    getSessions(buildId: string, query?: operations["getAutomateSessions"]["parameters"]["query"], options?: APIFetchOptions<operations["getAutomateSessions"]>): Promise<({
        browser: string;
        browser_version: string;
    } & {
        os: string;
        os_version: string;
        device: string;
        real_mobile: boolean;
    } & {
        hashed_id: string;
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        browserstack_status: string;
        reason: string;
        build_name: string;
        project_name: string;
        logs: string;
        browser_url: string;
        public_url: string;
        appium_logs_url: string;
        video_url: string;
        browser_console_logs_url: string;
        har_logs_url: string;
        selenium_logs_url: string;
        selenium_telemetry_logs_url: string;
        created_at: string;
    })[]>;
    /**
     * Retrieves the details of a specific session.
     * @param sessionId - The ID of the session to retrieve.
     * @param options - Additional options for the fetch request.
     * @returns A promise that resolves to the automation session data.
     */
    getSession(sessionId: string, options?: APIFetchOptions<operations["getAutomateSession"]>): Promise<{
        browser: string;
        browser_version: string;
    } & {
        os: string;
        os_version: string;
        device: string;
        real_mobile: boolean;
    } & {
        hashed_id: string;
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        browserstack_status: string;
        reason: string;
        build_name: string;
        project_name: string;
        logs: string;
        browser_url: string;
        public_url: string;
        appium_logs_url: string;
        video_url: string;
        browser_console_logs_url: string;
        har_logs_url: string;
        selenium_logs_url: string;
        selenium_telemetry_logs_url: string;
        created_at: string;
    }>;
    /**
     * Updates an automate session.
     *
     * @param sessionId - The ID of the session to update.
     * @param body - The request body containing the updated session data.
     * @param options - Additional options for the request.
     * @returns A promise that resolves to the updated automation session.
     */
    updateSession(sessionId: string, body: operations["updateAutomateSession"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["updateAutomateSession"]>): Promise<{
        browser: string;
        browser_version: string;
    } & {
        os: string;
        os_version: string;
        device: string;
        real_mobile: boolean;
    } & {
        hashed_id: string;
        name: string;
        duration: number;
        status: "running" | "timeout" | "failed" | "done";
        browserstack_status: string;
        reason: string;
        build_name: string;
        project_name: string;
        logs: string;
        browser_url: string;
        public_url: string;
        appium_logs_url: string;
        video_url: string;
        browser_console_logs_url: string;
        har_logs_url: string;
        selenium_logs_url: string;
        selenium_telemetry_logs_url: string;
        created_at: string;
    }>;
    /**
     * Deletes a session by its session ID.
     * @param sessionId The ID of the session to delete.
     * @param options Additional options for the delete request.
     * @returns A promise that resolves when the session is successfully deleted.
     */
    deleteSession(sessionId: string, options?: APIFetchOptions<operations["deleteAutomateSession"]>): Promise<{
        status?: string | undefined;
        message?: string | undefined;
    }>;
    /**
     * Deletes the specified sessions.
     * @param sessionIds - An array of session IDs to delete.
     * @param options - Additional options for the delete request.
     * @returns A promise that resolves when the delete request is complete.
     */
    deleteSessions(sessionIds: string[], options?: APIFetchOptions<operations["deleteAutomateSessions"]>): Promise<{
        message?: string | undefined;
    }>;
    /**
     * Uploads terminal logs for a specific build.
     * @param buildId - The ID of the build.
     * @param body - The request body containing the logs file and its filename.
     * @param options - Additional options for the request.
     * @returns A promise that resolves to the response of the request.
     */
    uploadBuildTerminalLogs(buildId: string, body: operations["uploadAutomateBuildTerminalLogs"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAutomateBuildTerminalLogs"]>): Promise<{
        message: string;
    }>;
    /**
     * Uploads terminal logs for a session.
     * @param sessionId - The ID of the session.
     * @param body - The request body containing the logs file and filename.
     * @param options - Additional options for the request.
     * @returns A promise that resolves to the response of the request.
     */
    uploadSessionTerminalLogs(sessionId: string, body: operations["uploadAutomateSessionTerminalLogs"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAutomateSessionTerminalLogs"]>): Promise<{
        message: string;
    }>;
    /**
     * Retrieves the logs for a specific session.
     *
     * @param sessionId - The ID of the session.
     * @param options - Additional options for the request.
     * @returns A promise that resolves with the logs of the session.
     */
    getSessionLogs(sessionId: string, options?: APIFetchOptions<operations["getAutomateSessionLogs"]>): Promise<string>;
    /**
     * Retrieves the network logs for a specific session.
     * @param sessionId - The ID of the session.
     * @param options - Additional options for the network logs request.
     * @returns A Promise that resolves to the network logs response.
     */
    getSessionNetworkLogs(sessionId: string, options?: APIFetchOptions<operations["getAutomateSessionNetworkLogs"]>): Promise<Record<string, never>>;
    /**
     * Retrieves the console logs for a specific session.
     * @param sessionId The ID of the session.
     * @param options Additional options for the request.
     * @returns A Promise that resolves to the console logs.
     */
    getSessionConsoleLogs(sessionId: string, options?: APIFetchOptions<operations["getAutomateSessionConsoleLogs"]>): Promise<string>;
    /**
     * Retrieves the Selenium logs for a specific session.
     * @param sessionId The ID of the session.
     * @param options Additional options for the request.
     * @returns A Promise that resolves to the Selenium logs.
     */
    getSessionSeleniumLogs(sessionId: string, options?: APIFetchOptions<operations["getAutomateSessionSeleniumLogs"]>): Promise<string>;
    /**
     * Retrieves the Appium logs for a specific session.
     *
     * @param sessionId - The ID of the session.
     * @param options - Additional options for the request.
     * @returns A Promise that resolves to the Appium logs.
     */
    getSessionAppiumLogs(sessionId: string, options?: APIFetchOptions<operations["getAutomateSessionAppiumLogs"]>): Promise<string>;
    /**
     * Retrieves the telemetry logs for a specific session.
     * @param sessionId - The ID of the session.
     * @param options - Additional options for the request.
     * @returns A Promise that resolves with the telemetry logs.
     */
    getSessionTelemetryLogs(sessionId: string, options?: APIFetchOptions<operations["getAutomateSessionTelemetryLogs"]>): Promise<{}>;
    /**
     * Uploads a media file to the BrowserStack Automate API.
     *
     * @param body - The content of the media file to be uploaded, along with its filename.
     * @param options - Additional options for the API request.
     * @returns A Promise that resolves to the response of the API request.
     */
    uploadMediaFile(body: operations["uploadAutomateMediaFile"]["requestBody"]["content"]["multipart/form-data"] & {
        filename: string;
    }, options?: APIFetchOptions<operations["uploadAutomateMediaFile"]>): Promise<{
        media_url: string;
    }>;
    /**
     * Retrieves the recent media files from the BrowserStack Automate API.
     * @param options - Optional fetch options for the API request.
     * @returns A promise that resolves with the response from the API.
     */
    getMediaFiles(options?: APIFetchOptions<operations["getAutomateMediaFiles"]>): Promise<{
        media_name: string;
        media_url: string;
        media_id: string;
        uploaded_at: string;
    }[]>;
    /**
     * Deletes a media file.
     * @param mediaId The ID of the media file to delete.
     * @param options Additional options for the delete request.
     * @returns A promise that resolves when the media file is successfully deleted.
     */
    deleteMediaFile(mediaId: string, options?: APIFetchOptions<operations["deleteAutomateMediaFile"]>): Promise<{
        success: boolean;
    }>;
}
